@@ -3,6 +3,7 @@ from hazelcast.protocol.client_message import ClientMessage
 from hazelcast.protocol.custom_codec import *
 from hazelcast.util import ImmutableLazyDataList
 from hazelcast.protocol.codec.client_message_type import *
+from hazelcast.six.moves import range
 
 REQUEST_TYPE = CLIENT_GETPARTITIONS
 RESPONSE_TYPE = 108
@@ -29,11 +30,11 @@ def decode_response(client_message, to_object=None):
     parameters = dict(partitions=None)
     partitions_size = client_message.read_int()
     partitions = {}
-    for partitions_index in xrange(0,partitions_size):
+    for partitions_index in range(0,partitions_size):
         partitions_key = AddressCodec.decode(client_message, to_object)
         partitions_val_size = client_message.read_int()
         partitions_val = []
-        for partitions_val_index in xrange(0, partitions_val_size):
+        for partitions_val_index in range(0, partitions_val_size):
             partitions_val_item = client_message.read_int()
             partitions_val.append(partitions_val_item)
         partitions[partitions_key] = partitions_val
