@@ -2,6 +2,7 @@ from hazelcast.protocol.client_message import ClientMessage
 from hazelcast.protocol.codec.map_message_type import *
 from hazelcast.protocol.event_response_const import *
 from hazelcast.serialization.bits import *
+from hazelcast.six.moves import range
 
 REQUEST_TYPE = MAP_ADDNEARCACHEENTRYLISTENER
 RESPONSE_TYPE = 104
@@ -47,7 +48,7 @@ def handle(client_message, handle_event_imapinvalidation=None, handle_event_imap
     if message_type == EVENT_IMAPBATCHINVALIDATION and handle_event_imapbatchinvalidation is not None:
         keys_size = client_message.read_int()
         keys = []
-        for keys_index in xrange(0, keys_size):
+        for keys_index in range(0, keys_size):
             keys_item = client_message.read_data()
             keys.append(keys_item)
         handle_event_imapbatchinvalidation(keys=keys)
