@@ -5,6 +5,7 @@ from hazelcast.exception import HazelcastSerializationError
 from hazelcast.serialization import bits
 from hazelcast.serialization.portable.classdef import ClassDefinition, ClassDefinitionBuilder, FieldType, FieldDefinition
 from hazelcast.serialization.portable.writer import ClassDefinitionWriter
+from hazelcast.six.moves import range
 
 
 class PortableContext(object):
@@ -32,7 +33,7 @@ class PortableContext(object):
         # field count
         field_count = data_in.read_int()
         offset = data_in.position()
-        for i in xrange(0, field_count):
+        for i in range(0, field_count):
             pos = data_in.read_int(offset + i * bits.INT_SIZE_IN_BYTES)
             data_in.set_position(pos)
 
